@@ -1,15 +1,14 @@
 use strict;
 use warnings;
-package Acme::Pi; # git description: v3.1412-2-g2d3de80
+package Acme::Pi;
 # ABSTRACT: Mmm, pie
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
 use utf8;
-# KEYWORDS: pi π
 
 my $version = atan2(1,1) * 4; $Acme::Pi::VERSION = "$version";
 
-use Exporter 'import';
+use Exporter 5.57 'import';
 our @EXPORT = ('$π');
 our $π = atan2(1,1) * 4;
 
@@ -48,20 +47,12 @@ It is intended that version parsers in the toolchain (L<Module::Metadata>,
 L<ExtUtils::MakeMaker>'s C<< MM->parse_version >>, L<Parse::PMFile>) should
 be capable of statically parsing this package's C<$VERSION>.
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-Pi>
-(or L<bug-Acme-Pi@rt.cpan.org|mailto:bug-Acme-Pi@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 ACKNOWLEDGEMENTS
 
 =for stopwords QA Hackathon
 
 This module was brought to you by the
-L<2014 QA Hackathon in Lyon|http://act.qa-hackathon.org/qa2014>, as well as
+L<2014 QA Hackathon in Lyon, France|http://act.qa-hackathon.org/qa2014>, as well as
 the number L<π|http://en.wikipedia.org/wiki/Pi>.
 
 =head1 AFTERWORD
@@ -115,6 +106,13 @@ L<lambda/λ>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-Pi>
+(or L<bug-Acme-Pi@rt.cpan.org|mailto:bug-Acme-Pi@rt.cpan.org>).
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
